| Title: | Dashboard for the interactive analysis and exploration of microbiome data |
|---|---|
| Description: | miaDash provides a Graphical User Interface for the exploration of microbiome data. This way, no knowledge of programming is required to perform analyses. Datasets can be imported, manipulated, analysed and visualised with a user-friendly interface. |
| Authors: | Giulio Benedetti [aut, cre] (ORCID: <https://orcid.org/0000-0002-8732-7692>), Akewak Jeba [ctb] (ORCID: <https://orcid.org/0009-0007-1347-7552>), Leo Lahti [aut] (ORCID: <https://orcid.org/0000-0001-5537-637X>) |
| Maintainer: | Giulio Benedetti <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.5.1 |
| Built: | 2026-05-11 16:39:48 UTC |
| Source: | https://github.com/bioc/miaDash |
miaDash is a web app that provides an interface to build and explore
TreeSummarizedExperiment
(TreeSE) objects by means of iSEE.
miaDash()miaDash()
An iSEE app with a custom landing page to
build TreeSE objects and explore mia datasets.
app <- miaDash() if (interactive()) { shiny::runApp(app) }app <- miaDash() if (interactive()) { shiny::runApp(app) }